==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/operation/GoTo3DViewActionType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GoTo3DViewActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GoTo3DViewActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="annotation" type="{http://schema.webpdf.de/1.0/operation}AnnotationSelectionType"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="index"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="relative" type="{http://schema.webpdf.de/1.0/operation}RelativeThreeDViewOperationType" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GoTo3DViewActionType", propOrder = {
    "annotation"
})
public class GoTo3DViewActionType
    extends ActionEventType
{

    @XmlElement(required = true)
    protected AnnotationSelectionType annotation;
    @XmlAttribute(name = "index")
    protected Integer index;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "relative")
    protected RelativeThreeDViewOperationType relative;

    /**
     * Gets the value of the annotation property.
     * 
     * @return
     *     possible object is
     *     {@link AnnotationSelectionType }
     *     
     */
    public AnnotationSelectionType getAnnotation() {
        return annotation;
    }

    /**
     * Sets the value of the annotation property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnnotationSelectionType }
     *     
     */
    public void setAnnotation(AnnotationSelectionType value) {
        this.annotation = value;
    }

    public boolean isSetAnnotation() {
        return (this.annotation!= null);
    }

    /**
     * Gets the value of the index property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getIndex() {
        return index;
    }

    /**
     * Sets the value of the index property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setIndex(int value) {
        this.index = value;
    }

    public boolean isSetIndex() {
        return (this.index!= null);
    }

    public void unsetIndex() {
        this.index = null;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public boolean isSetName() {
        return (this.name!= null);
    }

    /**
     * Gets the value of the relative property.
     * 
     * @return
     *     possible object is
     *     {@link RelativeThreeDViewOperationType }
     *     
     */
    public RelativeThreeDViewOperationType getRelative() {
        return relative;
    }

    /**
     * Sets the value of the relative property.
     * 
     * @param value
     *     allowed object is
     *     {@link RelativeThreeDViewOperationType }
     *     
     */
    public void setRelative(RelativeThreeDViewOperationType value) {
        this.relative = value;
    }

    public boolean isSetRelative() {
        return (this.relative!= null);
    }

}

==> webpdf-wsclient-2.0.2-sources.jar: net/webpdf/wsclient/schema/operation/GoTo3DViewActionType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GoTo3DViewActionType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GoTo3DViewActionType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}ActionEventType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="annotation" type="{http://schema.webpdf.de/1.0/operation}AnnotationSelectionType"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="index"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://www.w3.org/2001/XMLSchema}int"&gt;
 *             &lt;minInclusive value="0"/&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="name" type="{http://www.w3.org/2001/XMLSchema}string" /&gt;
 *       &lt;attribute name="relative" type="{http://schema.webpdf.de/1.0/operation}RelativeThreeDViewOperationType" default="Default" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GoTo3DViewActionType", propOrder = {
    "annotation"
})
public class GoTo3DViewActionType
    extends ActionEventType
{

    @XmlElement(required = true)
    protected AnnotationSelectionType annotation;
    @XmlAttribute(name = "index")
    protected Integer index;
    @XmlAttribute(name = "name")
    protected String name;
    @XmlAttribute(name = "relative")
    protected RelativeThreeDViewOperationType relative;

    /**
     * Gets the value of the annotation property.
     * 
     * @return
     *     possible object is
     *     {@link AnnotationSelectionType }
     *     
     */
    public AnnotationSelectionType getAnnotation() {
        return annotation;
    }

    /**
     * Sets the value of the annotation property.
     * 
     * @param value
     *     allowed object is
     *     {@link AnnotationSelectionType }
     *     
     */
    public void setAnnotation(AnnotationSelectionType value) {
        this.annotation = value;
    }

    public boolean isSetAnnotation() {
        return (this.annotation!= null);
    }

    /**
     * Gets the value of the index property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getIndex() {
        return index;
    }

    /**
     * Sets the value of the index property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setIndex(int value) {
        this.index = value;
    }

    public boolean isSetIndex() {
        return (this.index!= null);
    }

    public void unsetIndex() {
        this.index = null;
    }

    /**
     * Gets the value of the name property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setName(String value) {
        this.name = value;
    }

    public boolean isSetName() {
        return (this.name!= null);
    }

    /**
     * Gets the value of the relative property.
     * 
     * @return
     *     possible object is
     *     {@link RelativeThreeDViewOperationType }
     *     
     */
    public RelativeThreeDViewOperationType getRelative() {
        if (relative == null) {
            return RelativeThreeDViewOperationType.DEFAULT;
        } else {
            return relative;
        }
    }

    /**
     * Sets the value of the relative property.
     * 
     * @param value
     *     allowed object is
     *     {@link RelativeThreeDViewOperationType }
     *     
     */
    public void setRelative(RelativeThreeDViewOperationType value) {
        this.relative = value;
    }

    public boolean isSetRelative() {
        return (this.relative!= null);
    }

}
